import sys
from PyQt5 import QtWidgets
from interfaz import Ui_MainWindow
import serial

class MainApp(QtWidgets.QMainWindow):
    def __init__(self):
        super().__init__()
        self.ui = Ui_MainWindow()
        self.ui.setupUi(self)

        # Conectar los botones y entradas a sus funciones correspondientes
        self.ui.boton_izquierda.pressed.connect(self.move_servo_to_0)
        self.ui.boton_derecha.pressed.connect(self.move_servo_to_180)
        self.ui.spinBox.valueChanged.connect(self.set_servo_angle_spinbox)
        self.ui.lineEdit.returnPressed.connect(self.set_servo_angle_lineedit)

        # Inicializar la conexión serie
        try:
            self.serial_port = serial.Serial('COM4', 115200)  # CAMBIA EL PUERTO 
        except serial.SerialException as e:
            print(f"Error al abrir el puerto serie: {e}")
            self.serial_port = None

    def move_servo_to_0(self):
        # Enviar comando para mover el servo a 0 grados
        self.send_servo_command('L')
        self.update_indicator(0)

    def move_servo_to_180(self):
        # Enviar comando para mover el servo a 180 grados
        self.send_servo_command('R')
        self.update_indicator(180)

    def set_servo_angle_spinbox(self):
        # Obtener el ángulo del spinbox y enviar el comando
        angle = self.ui.spinBox.value()
        self.send_servo_command(str(angle))
        self.update_indicator(angle)

    def set_servo_angle_lineedit(self):
        # Obtener el ángulo del lineedit y enviar el comando
        try:
            angle = int(self.ui.lineEdit.text())
            if 0 <= angle <= 180:
                self.send_servo_command(str(angle))
                self.update_indicator(angle)
                self.ui.spinBox.setValue(angle)
            else:
                self.ui.label_2.setText("Invalid input")
        except ValueError:
            self.ui.label_2.setText("Invalid input")

    def update_indicator(self, angle):
        # Actualizar el QLabel para mostrar el ángulo actual
        self.ui.label_2.setStyleSheet("QLabel{\n"
"    font-size: 14px;\n"
"    color: #FFFFFF;\n"
"    background-color: #28a745; /* Fondo verde */\n"
"    border: 2px solid #28a745; /* Borde verde */\n"
"    padding: 5px;\n"
"    border-radius: 5px;\n"
"}")
        self.ui.label_2.setText(f"Moved to {angle}°")

    def send_servo_command(self, command):
        # Enviar el comando al puerto serie
        if self.serial_port:
            try:
                self.serial_port.write((command + '\n').encode())
                print(f"Command sent: {command}")  # Mensaje de depuración
            except Exception as e:
                print(f"Error sending command: {e}")

if __name__ == "__main__":
    app = QtWidgets.QApplication(sys.argv)
    window = MainApp()
    window.show()
    sys.exit(app.exec_())
